package cn.newfeifan.mall.module.member.service.auth;

import cn.newfeifan.mall.module.member.controller.app.auth.vo.*;

import javax.validation.Valid;

/**
 * 会员的认证 Service 接口
 * <p>
 * 提供用户的账号密码登录、token 的校验等认证相关的功能
 *
 * @author 非繁源码
 */
public interface MemberAuthService {

    /**
     * 手机 + 密码登录
     *
     * @param reqVO 登录信息
     * @return 登录结果
     */
    AppAuthLoginRespVO login(@Valid AppAuthLoginReqVO reqVO);

    /**
     * 基于 token 退出登录
     *
     * @param token token
     */
    void logout(String token);

    /**
     * 获得社交认证 URL
     *
     * @param type        社交平台类型
     * @param redirectUri 跳转地址
     * @return 认证 URL
     */
    String getSocialAuthorizeUrl(Integer type, String redirectUri);

    /**
     * 给用户发送短信验证码
     *
     * @param userId 用户编号
     * @param reqVO  发送信息
     */
    void sendSmsCode(Long userId, AppAuthSmsSendReqVO reqVO);

    /**
     * 校验短信验证码是否正确
     *
     * @param userId 用户编号
     * @param reqVO  校验信息
     */
    void validateSmsCode(Long userId, AppAuthSmsValidateReqVO reqVO);

    /**
     * 刷新访问令牌
     *
     * @param refreshToken 刷新令牌
     * @return 登录结果
     */
    AppAuthLoginRespVO refreshToken(String refreshToken);

    /**
     * 使用手机号 + 验证码注册
     *
     * @param reqVO 注册信息
     * @return 登录结果
     */
    AppAuthLoginRespVO smsRegister(AppAuthSmsRegisterReqVO reqVO);

    /**
     * 跳转登录
     * @return 跳转登录
     */
    String redirectLogin();

    /**
     * 注销用户
     * @param loginUserId 用户id
     */
    void deleteUser(Long loginUserId);
}
